- x
-
DB::x -- break script execution DB::x 'str' -- break script execution if $DB::x{ 'str' } is true
The second form is useful in cases when some code is executed frequently. Thus we can not put DB::x expression there. So we write 'DB::x = "str"' there. This means execution will be stopped there only when '$DB::x{str} = 1' expression will be reached in a main script.
1 POD Error
The following errors were encountered while parsing the POD:
- Around line 81:
'=item' outside of any '=over'
=over without closing =back